# Enhancements related to static code analysis

See also [Issue 18](https://bitbucket.org/fluiddyn/fluidpythran/issues/18/)

- 1st step: issues 6 and 7

- issue 29 is more difficult

- it's also interesting to take into account [issue 32 (Refactoring frontend /
  backends as extensions)](https://bitbucket.org/fluiddyn/fluidpythran/issues/32)
